==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/lib/l10n/hy.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Անհայտ նիշքի տեսակ",
    "Invalid image" : "Անվավեր նկար",
    "Files" : "Ֆայլեր",
    "today" : "այսօր",
    "seconds ago" : "վրկ. առաջ",
    "__language_name__" : "Հայերեն",
    "Settings" : "կարգավորումներ",
    "Log out" : "Դուրս գալ",
    "Email" : "Էլ․փոստ",
    "Address" : "Հասցե",
    "About" : "էջի վերաբերյալ",
    "Sunday" : "Կիրակի",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sun." : "Կիր.",
    "Mon." : "Երկ.",
    "Tue." : "Երք.",
    "Wed." : "Չոր.",
    "Thu." : "Հնգ.",
    "Fri." : "Ուրբ.",
    "Sat." : "Շաբ.",
    "Su" : "Կիր",
    "Mo" : "Երկ",
    "Tu" : "Երք",
    "We" : "Չոր",
    "Th" : "Հնգ",
    "Fr" : "Ուրբ",
    "Sa" : "Շաբ",
    "January" : "Հունվար",
    "February" : "Փետրվար",
    "March" : "Մարտ",
    "April" : "Ապրիլ",
    "May" : "Մայիս",
    "June" : "Հունիս",
    "July" : "Հուլիս",
    "August" : "Օգոստոս",
    "September" : "Սեպտեմբեր",
    "October" : "Հոկտեմբեր",
    "November" : "Նոյեմբեր",
    "December" : "Դեկտեմբեր",
    "Jan." : "Հնվ.",
    "Feb." : "Փտվ.",
    "Mar." : "Մրտ.",
    "Apr." : "Ապր.",
    "May." : "Մյս.",
    "Jun." : "Հնս.",
    "Jul." : "Հլս.",
    "Aug." : "Օգս.",
    "Sep." : "Սեպ.",
    "Oct." : "Հոկ.",
    "Nov." : "Նոյ.",
    "Dec." : "Դեկ.",
    "Translate" : "Թարգմանել",
    "File name contains at least one invalid character" : "Ֆայլի անունը առնվազն մի անվավեր նիշ է պարունակում"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/lib/l10n/hy.js <==
OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "Անհայտ նիշքի տեսակ",
    "Invalid image" : "Անվավեր նկար",
    "Files" : "Ֆայլեր",
    "today" : "այսօր",
    "seconds ago" : "վրկ. առաջ",
    "__language_name__" : "Հայերեն",
    "Settings" : "կարգավորումներ",
    "Log out" : "Դուրս գալ",
    "Accounts" : "Accounts",
    "Email" : "Էլ․փոստ",
    "Address" : "Հասցե",
    "About" : "էջի վերաբերյալ",
    "Sunday" : "Կիրակի",
    "Monday" : "Երկուշաբթի",
    "Tuesday" : "Երեքշաբթի",
    "Wednesday" : "Չորեքշաբթի",
    "Thursday" : "Հինգշաբթի",
    "Friday" : "Ուրբաթ",
    "Saturday" : "Շաբաթ",
    "Sun." : "Կիր.",
    "Mon." : "Երկ.",
    "Tue." : "Երք.",
    "Wed." : "Չոր.",
    "Thu." : "Հնգ.",
    "Fri." : "Ուրբ.",
    "Sat." : "Շաբ.",
    "Su" : "Կիր",
    "Mo" : "Երկ",
    "Tu" : "Երք",
    "We" : "Չոր",
    "Th" : "Հնգ",
    "Fr" : "Ուրբ",
    "Sa" : "Շաբ",
    "January" : "Հունվար",
    "February" : "Փետրվար",
    "March" : "Մարտ",
    "April" : "Ապրիլ",
    "May" : "Մայիս",
    "June" : "Հունիս",
    "July" : "Հուլիս",
    "August" : "Օգոստոս",
    "September" : "Սեպտեմբեր",
    "October" : "Հոկտեմբեր",
    "November" : "Նոյեմբեր",
    "December" : "Դեկտեմբեր",
    "Jan." : "Հնվ.",
    "Feb." : "Փտվ.",
    "Mar." : "Մրտ.",
    "Apr." : "Ապր.",
    "May." : "Մյս.",
    "Jun." : "Հնս.",
    "Jul." : "Հլս.",
    "Aug." : "Օգս.",
    "Sep." : "Սեպ.",
    "Oct." : "Հոկ.",
    "Nov." : "Նոյ.",
    "Dec." : "Դեկ.",
    "Translate" : "Թարգմանել"
},
"nplurals=2; plural=(n != 1);");
